<?php

/**
 * @file
 * Rating type edit form.
 */

/**
 * Generates the Rating type editing form.
 */
function rating_entity_type_form($form, &$form_state, $rating_type, $op = 'edit') {

  if ($op == 'clone') {
    $rating_type->name .= ' (cloned)';
  }

  $form['name'] = array(
    '#title' => t('Type title'),
    '#type' => 'textfield',
    '#default_value' => check_plain($rating_type->name),
    '#description' => t('The human-readable name of this rating type. Will be used as reason for penalties.'),
    '#required' => TRUE,
    '#size' => 30,
  );

  $form['machine_name'] = array(
    '#type' => 'machine_name',
    '#default_value' => isset($rating_type->machine_name) ? check_plain($rating_type->machine_name) : '',
    '#maxlength' => 128,
    '#disabled' => $rating_type->isLocked() && $op != 'clone',
    '#machine_name' => array(
      'exists' => 'rating_entity_types',
      'source' => array('name'),
    ),
    '#description' => t('A unique machine-readable name for this rating type. It must only contain lowercase letters, numbers, and underscores.'),
  );

  $form['description'] = array(
    '#title' => t('Description'),
    '#type' => 'textarea',
    '#default_value' => isset($rating_type->description) ? check_plain($rating_type->description) : '',
    '#description' => t('Description about the rating type.'),
  );

  $form['tid'] = array(
    '#title' => t('Choose category'),
    '#type' => 'select',
    '#default_value' => $rating_type->tid,
    '#options' => rating_entity_get_category_terms(),
    '#required' => TRUE,
  );

  $form['points'] = array(
    '#title' => t('Amount of points'),
    '#type' => 'textfield',
    '#default_value' => check_plain($rating_type->points),
    '#description' => t('Amount of points that will receive entity.'),
    '#element_validate' => array('element_validate_integer'),
    '#required' => TRUE,
    '#size' => 30,
  );

  $form['actions'] = array('#type' => 'actions');
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save rating type'),
    '#weight' => 40,
  );

  if (!$rating_type->isLocked() && $op != 'add' && $op != 'clone') {
    $form['actions']['delete'] = array(
      '#type' => 'submit',
      '#value' => t('Delete rating type'),
      '#weight' => 45,
      '#limit_validation_errors' => array(),
      '#submit' => array('rating_entity_type_form_submit_delete')
    );
  }
  erpal_project_rating_form_include($form_state, 'admin');

  return $form;
}

/**
 * Validate callback for creating/editing rating type form.
 */
function rating_entity_type_form_validate($form, $form_state) {

  if (drupal_strlen($form_state['values']['description']) > 255) {

    form_set_error('description', t('Description field must be a less than 256 chars.'));
  }
}

/**
 * Submit handler for creating/editing rating type.
 */
function rating_entity_type_form_submit(&$form, &$form_state) {

  $rating_type = entity_ui_form_submit_build_entity($form, $form_state);
  rating_entity_type_save($rating_type);

  $form_state['redirect'] = RATING_BUNDLE_ADMIN_PATH;
}

/**
 * Submit handler for delete rating type form.
 */
function rating_entity_type_form_submit_delete(&$form, &$form_state) {

  $form_state['redirect'] = RATING_BUNDLE_ADMIN_PATH . '/manage/' . $form_state['rating_entity_type']->machine_name . '/delete';
}

// -----------------------------------------------------------------------
// Rating support form.

/**
 * Attach rating support vertical tab to 'project type edit' and 'project edit' forms.
 */
function _erpal_project_rating_attach_rating_support_form(&$form, &$form_state, $form_id) {

  $is_type_project_edit_form = ($form_id == 'node_type_form' && $form['#node_type']->type == RATING_PROJECT_NODE_TYPE);
  $is_project_edit_form = ($form_id == RATING_PROJECT_NODE_TYPE . '_node_form');

  if ($is_type_project_edit_form || $is_project_edit_form) {

    $supported_all_projects = variable_get('erpal_project_rating_support_erpal_project', 0);
    $rating_support_enabled = $supported_all_projects;

    // Check this project if it is project edit form.
    if (!$supported_all_projects && $is_project_edit_form) {
      $rating_support_enabled = erpal_project_rating_is_node_support_rating($form['#node']);
    }

    $form['erpal_project_rating'] = array(
      '#type' => 'fieldset',
      '#title' => t('Penalty rating'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#group' => 'additional_settings',
    );
    $form['erpal_project_rating']['erpal_project_rating_support'] = array(
      '#type' => 'checkbox',
      '#title' => t('Support penalty rating'),
      '#disabled' => ($supported_all_projects && !$is_type_project_edit_form),
      '#default_value' => $rating_support_enabled,
    );

    $form_state['supported_for_all_projects'] = $supported_all_projects;

    // Use 'submit' function for button, because Project nid not exists for created project.
    if ($is_project_edit_form) {
      $form['actions']['submit']['#submit'][] = '_erpal_project_rating_attach_rating_support_form_submit';
    }
    else {
      $form['#submit'][] = '_erpal_project_rating_attach_rating_support_form_submit';
    }

    erpal_project_rating_form_include($form_state, 'admin');
  }
}

/**
 * Submission handler for rating support form.
 */
function _erpal_project_rating_attach_rating_support_form_submit($form, &$form_state) {

  $is_project_edit_form = ($form_state['build_info']['form_id'] == RATING_PROJECT_NODE_TYPE . '_node_form');
  $rating_support_enabled_new_value = $form_state['values']['erpal_project_rating_support'];
  $supported_all_projects = $form_state['supported_for_all_projects'];

  $op = 'not_update';
  if ($is_project_edit_form) {

    $current_project_id = $form_state['values']['nid'];
    $supported_projects = variable_get('erpal_project_rating_support_erpal_projects', array());

    if (!empty($supported_projects[$current_project_id]) &&
      ($supported_all_projects || (!$supported_all_projects && !$rating_support_enabled_new_value))) {

      unset($supported_projects[$current_project_id]);
      variable_set('erpal_project_rating_support_erpal_projects', $supported_projects);
      $op = 'disable';
    }
    elseif (!$supported_all_projects && $rating_support_enabled_new_value) {

      $supported_projects[$current_project_id] = $current_project_id;
      variable_set('erpal_project_rating_support_erpal_projects', $supported_projects);
      $op = 'enable';
    }
  }
  elseif ($supported_all_projects <> $rating_support_enabled_new_value) {

    $op = $rating_support_enabled_new_value ? 'enable' : 'disable';
    if ($op == 'disable') {
      variable_set('erpal_project_rating_support_erpal_projects', array());
    }
  }

  if ($op <> 'not_update') {

    $project_id = isset($current_project_id) ? $current_project_id : NULL;
    module_invoke_all('erpal_project_rating_support_update', $op, $project_id);
  }
}

/**
 * Check if project or task's parent project supports rating.
 *
 * @param $node
 *   Node object. Can be 'project' or 'task' node type.
 *
 * @return bool
 *   TRUE if node supports rating.
 */
function _erpal_project_rating_is_node_support_rating($node) {

  if (empty($node->nid) || !($node->type == RATING_PROJECT_NODE_TYPE || $node->type == RATING_TASK_NODE_TYPE)) {
    return FALSE;
  }

  // If $node is project.
  if ($node->type == RATING_PROJECT_NODE_TYPE) {
    $project_id = $node->nid;
  }
  else {
    // $node is task or something else.
    $project_id = _erpal_projects_helper_has_project($node->nid);
    if (empty($project_id)) {
      return FALSE;
    }
  }

  $supported_projects = variable_get('erpal_project_rating_support_erpal_projects', array());
  if (!empty($supported_projects[$project_id])) {
    return TRUE;
  }
  return variable_get('erpal_project_rating_support_erpal_project', 0);
}
