<?php

/**
 * @file
 * ERPAL Project rating module API.
 */


/**
 * Output status light for node.
 *
 * Output status as single light by default,
 * Output status as lights by categories if $by_category is TRUE.
 *
 * @param $node
 *   Node object for which status light will be show.
 * @param bool $by_category
 *   Output status as lights by categories if TRUE.
 *
 * @return string
 *  return HTML with status light.
 */
function erpal_project_rating_light_status_view($node, $by_category = FALSE) {
  erpal_project_rating_include('view');

  return _erpal_project_rating_light_status_view($node, $by_category);
}

/**
 * Returns status id by nid.
 *
 * @param integer $nid
 *   Node ID for which status will be returned.
 *
 * @return int
 *   Status ID. Example: 0.
 */
function erpal_project_rating_get_status($nid) {
  erpal_project_rating_include('cache_node_status');

  return _erpal_project_rating_get_status($nid);
}

/**
 * Returns array of status ids for node, keyed by category id.
 *
 * @param $nid
 *   Node ID for which statuses will be returned.
 *
 * @return array
 *   An array of status ids, keyed by category id.
 *   Example: array(308 => 0, 309 => 2, 310 => 1).
 */
function erpal_project_rating_get_status_by_category($nid) {
  erpal_project_rating_include('cache_term');

  return _erpal_project_rating_get_status_by_category($nid);
}

/**
 * Update points/status for node.
 *
 * @param $nid
 *   Node ID for which status will be updated.
 */
function erpal_project_rating_cache_update($nid) {
  erpal_project_rating_include('cache_node_status');
  erpal_project_rating_include('cache_term');

  erpal_project_rating_cache_term_update($nid);
  erpal_project_rating_cache_node_update($nid);
}

/**
 * Update points/status for nodes using batch.
 *
 * @param $nids
 *   Node IDs for which status will be updated.
 */
function erpal_project_rating_cache_update_batch($nids) {
  if (empty($nids)) {
    return;
  }

  $batch = array(
    'operations' => array(0 => array('_erpal_project_rating_cache_update_batch', array(array_values($nids)))),
    'file' => drupal_get_path('module', 'erpal_project_rating') . '/includes/recalculation.inc',
  );

  batch_set($batch);
  batch_process();
}

/**
 * Check if project or task's parent project supports rating.
 *
 * @param $node
 *   Can be 'project' or 'task' node type.
 *
 * @return bool
 *   TRUE if node supports rating.
 */
function erpal_project_rating_is_node_support_rating($node) {
  erpal_project_rating_include('admin');

  return _erpal_project_rating_is_node_support_rating($node);
}

/**
 * Returns taxonomy terms from default Rating categories vocabulary.
 *
 * @return array
 *  An array of term names, keyed by term id.
 *  Example: array(308 => 'Administration', 309 => 'Development').
 */
function rating_entity_get_category_terms() {
  $vocabulary = taxonomy_vocabulary_machine_name_load(RATING_CATEGORY_VOC_NAME);
  $terms = taxonomy_get_tree($vocabulary->vid);

  $result = array();
  foreach ($terms as $term) {
    $result[$term->tid] = check_plain($term->name);
  }

  return $result;
}

/**
 * Include .inc files in a form context.
 *
 * Save information in the form_state so that cached forms will properly include things.
 *
 * @param $filename
 *   The base file name to be included.
 */
function erpal_project_rating_form_include(&$form_state, $filename) {
  if (!isset($form_state['build_info']['args'])) {
    $form_state['build_info']['args'] = array();
  }

  form_load_include($form_state, 'inc', 'erpal_project_rating', 'includes/' . $filename);
}