<?php

/**
 * @file
 * A classes for rating.
 */

/**
 * RatingEntity class.
 */
class RatingEntity extends Entity {

  /**
   * The type of this rating.
   *
   * @var string
   */
  public $rating_type;

  /**
   * Node ID, to which rating was added.
   *
   * @var integer
   */
  public $nid;

  /**
   * Amount of points that was added for the rating.
   *
   * @var integer
   */
  public $points;

  /**
   * The Unix timestamp when the rating was created.
   *
   * @var integer
   */
  public $created;

  protected function defaultLabel() {
    return $this->rating_type;
  }

  public function __construct($values = array()) {
    $values += array(
      'created' => REQUEST_TIME,
    );
    parent::__construct($values, 'rating_entity');
  }
}

/**
 * RatingEntityType class.
 */
class RatingEntityType extends Entity {

  /**
   * The machine-readable name of this rating type.
   *
   * @var string
   */
  public $machine_name;

  /**
   * The human-readable name of this rating type.
   *
   * @var string
   */
  public $name;

  /**
   * The description for rating type.
   *
   * @var string
   */
  public $description;

  /**
   * Taxonomy category id of this rating type.
   *
   * @var integer
   */
  public $tid;

  /**
   * Default count of points what will be added for this rating type.
   *
   * @var integer
   */
  public $points;

  /**
   * The rating type weight.
   *
   * @var integer
   */
  public $weight = 0;

  public function __construct($values = array()) {
    parent::__construct($values, 'rating_entity_type');
  }

  function isLocked() {
    return isset($this->status) && empty($this->is_new) && (($this->status & ENTITY_IN_CODE) || ($this->status & ENTITY_FIXED));
  }
}

/**
 * @see hook_entity_property_info()
 */
class RatingEntityMetadataController extends EntityDefaultMetadataController {

  public function entityPropertyInfo() {
    $info = parent::entityPropertyInfo();

    $properties = &$info['rating_entity']['properties'];
    $properties['created'] = array(
      'label' => t("Date added"),
      'type' => 'date',
      'description' => t("The date the penalty was added."),
      'setter callback' => 'entity_property_verbatim_set',
      'schema field' => 'created',
    );
    $properties['rating_type'] = array(
      'label' => t("Penalty type"),
      'type' => 'rating_entity_type',
      'description' => t("The type of the penalty."),
      'setter callback' => 'entity_property_verbatim_set',
      'required' => TRUE,
      'schema field' => 'rating_type',
    );
    return $info;
  }

}

/**
 * @see hook_entity_property_info()
 */
class RatingEntityTypeMetadataController extends EntityDefaultMetadataController {

  public function entityPropertyInfo() {
    $info = parent::entityPropertyInfo();

    $properties = &$info['rating_entity_type']['properties'];
    $properties['tid'] = array(
      'label' => t("Category ID"),
      'type' => 'taxonomy_term',
      'description' => t("The category of the penalty."),
      'setter callback' => 'entity_property_verbatim_set',
      'required' => TRUE,
      'schema field' => 'tid',
    );
    return $info;
  }

}
