<?php

/**
 * @file
 * Rating entity type API.
 */


/**
 * Access callback for rating type.
 */
function rating_entity_type_access() {
  return user_access('administer project rating');
}

/**
 * Load rating type object.
 *
 * @param string $type_name
 *   Machine name of Rating type.
 */
function rating_entity_type_load($type_name) {
  return rating_entity_types($type_name);
}

/**
 * Load rating types by tid.
 *
 * @param integer $tid
 *   Category id for which rating types will be loaded.
 *
 * @return array
 *   An array of RatingEntityType objects.
 */
function rating_entity_type_load_multiple_by_tid($tid) {

  $query = new EntityFieldQuery();
  $results = $query->entityCondition('entity_type', 'rating_entity_type')
    ->propertyCondition('tid', $tid, is_array($tid) ? 'IN' : '=')
    ->execute();

  return isset($results['rating_entity_type']) ? entity_load_multiple_by_name('rating_entity_type', array_keys($results['rating_entity_type'])) : array();
}

/**
 * List of rating types by type name.
 *
 * @param string $type_name
 *   (optional) Machine name of Rating type.
 *
 * @return RatingEntityType|array
 *   Single RatingEntityType object by given type name or an array of RatingEntityType objects
 *   if none is specified.
 */
function rating_entity_types($type_name = NULL) {
  $rating_types = entity_load_multiple_by_name('rating_entity_type', isset($type_name) ? array($type_name) : FALSE);
  return isset($type_name) ? reset($rating_types) : $rating_types;
}

/**
 * Returns rating type category by rating type name.
 *
 * @param string $type_name
 *   Machine name of Rating type.
 *
 * @return integer|NULL
 *   Category Id for given type name or NULL if in this type non exists.
 */
function rating_entity_type_tid_by_name($type_name) {
  $rating_type = rating_entity_types($type_name);
  return !empty($rating_type) ? $rating_type->tid : NULL;
}

/**
 * Save rating type entity.
 *
 * @param RatingEntityType $rating
 *   RatingEntityType object.
 */
function rating_entity_type_save($rating_type) {
  entity_save('rating_entity_type', $rating_type);
}

/**
 * Delete single rating type entity.
 *
 * @param RatingEntityType $rating
 *   RatingEntityType object.
 */
function rating_entity_type_delete($rating_type) {
  entity_delete('rating_entity_type', entity_id('rating_entity_type', $rating_type));
}