<?php

/**
 * @file
 * Functions for view status light.
 */

/**
 * Output status light for node.
 *
 * Output status as single light by default,
 * Output status as lights by categories if $by_category is TRUE.
 *
 * @param object $node
 *   Node object for which status light will be show.
 * @param bool $by_category
 *   Output status as lights by categories if TRUE.
 *
 * @return string
 *  return HTML with status light.
 */
function _erpal_project_rating_light_status_view($node, $by_category = FALSE) {

  if (!user_access('view project rating light')) {
    return '';
  }

  if ($by_category) {

    return _erpal_project_rating_light_status_view_by_category($node);
  }
  elseif (erpal_project_rating_is_node_support_rating($node)) {

    $task_status = erpal_project_rating_get_status($node->nid);

    return theme('erpal_project_rating_light', array('status' => $task_status));
  }

  return '';
}

/**
 * Helper function to output status lights by category.
 *
 * @param object $node
 *   Node object for which status light will be show.
 *
 * @return string
 *  return HTML with status lights by category.
 */
function _erpal_project_rating_light_status_view_by_category($node) {

  if (erpal_project_rating_is_node_support_rating($node)) {

    $statuses_by_category = erpal_project_rating_get_status_by_category($node->nid);

    $items = array();
    $all_terms = rating_entity_get_category_terms();

    foreach ($statuses_by_category as $tid => $status) {

      $light_status = theme('erpal_project_rating_light', array('status' => $status));

      // Output as link to penalties in category page for Tasks.
      if ($node->type == RATING_TASK_NODE_TYPE) {

        $light_status = l($light_status,
          'node/' . $node->nid . '/penalties/' . $tid,
          array('attributes' => array('class' => 'rating-light-link'), 'html' => TRUE)
        );
      }

      $items[$tid] = theme('erpal_project_rating_light_with_category', array('light_status' => $light_status, 'category' => $all_terms[$tid]));
    }

    return theme('item_list', array('items' => $items), array('attributes' => array('class' => 'rating-light-list')));
  }

  return '';
}